import sys
import yt_dlp


def needmusic(url=None):
    """Download audio from YouTube video."""
    url = url or (sys.argv[1] if len(sys.argv) > 1 else None)
    if not url:
        print("Usage: needmusic <youtube_url>")
        return
    ydl_opts = {"format": "bestaudio/best"}
    with yt_dlp.YoutubeDL(ydl_opts) as ydl:
        ydl.download([url])


def needvideo(url=None):
    """Download video from YouTube."""
    url = url or (sys.argv[1] if len(sys.argv) > 1 else None)
    if not url:
        print("Usage: needvideo <youtube_url>")
        return
    ydl_opts = {"format": "best"}
    with yt_dlp.YoutubeDL(ydl_opts) as ydl:
        ydl.download([url])


from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="alper",
    version="0.1.4",
    packages=find_packages(),
    url="https://github.com/alperugurca/alper",
    project_urls={
        "Source": "https://github.com/alperugurca/alper",
        "Bug Tracker": "https://github.com/alperugurca/alper/issues",
    },
    install_requires=["yt-dlp"],
    entry_points={
        "console_scripts": [
            "needmusic=alper:needmusic",
            "needvideo=alper:needvideo",
        ],
    },
    long_description=long_description,
    long_description_content_type="text/markdown",
)